Gitea
=====

`Gitea <https://gitea.io/>`__ is available at `gitea.example.com`.
The user with administrative rights is `root`. Its password can be set
as documented in `this file
<https://lab.enough.community/main/infrastructure/-/blob/master/playbooks/gitlab/roles/gitlab/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/host_vars/gitea/gitea.yml`
file.
